==> marketplace-ui-3.6.0.tgz: package/src/components/Providers.tsx <==
import { WalletModalProvider } from "@solana/wallet-adapter-react-ui";
import {
  Notification,
  StrataProviders
} from "@strata-foundation/react";
import React from "react";
import toast from "react-hot-toast";
import { MarketplaceProviders } from "./MarketplaceProviders";
import { Wallet } from "./Wallet";

export const Providers = ({
  children,
  cluster,
}: {
  cluster?: string;
  children: React.ReactNode;
}) => {
  const onError = React.useCallback(
    (error: Error) => {
      console.error(error);
      if (
        error.message?.includes(
          "Attempt to debit an account but found no record of a prior credit."
        )
      ) {
        error = new Error("Not enough SOL to perform this action");
      }

      const code = (error.message?.match("custom program error: (.*)") ||
        [])[1];
      if (code == "0x1") {
        error = new Error("Insufficient balance.");
      } else if (code === "0x0") {
        error = new Error("Blockhash expired. Please retry");
      }

      toast.custom((t) => (
        <Notification
          type="error"
          show={t.visible}
          heading={error.name}
          // @ts-ignore
          message={error.message || error.msg || error.toString()}
          onDismiss={() => toast.dismiss(t.id)}
        />
      ));
    },
    [toast]
  );

  return (
    <Wallet cluster={cluster}>
      <WalletModalProvider>
        <StrataProviders onError={onError} resetCSS>
          <MarketplaceProviders>{children}</MarketplaceProviders>
        </StrataProviders>
      </WalletModalProvider>
    </Wallet>
  );
};

==> marketplace-ui-3.7.0.tgz: package/src/components/Providers.tsx <==
import { WalletModalProvider } from "@solana/wallet-adapter-react-ui";
import {
  Notification,
} from "@strata-foundation/react";
import React from "react";
import toast from "react-hot-toast";
import { MarketplaceProviders } from "./MarketplaceProviders";
import { Wallet } from "./Wallet";

export const Providers = ({
  children,
  cluster,
}: {
  cluster?: string;
  children: React.ReactNode;
}) => {
  const onError = React.useCallback(
    (error: Error) => {
      console.error(error);
      if (
        error.message?.includes(
          "Attempt to debit an account but found no record of a prior credit."
        )
      ) {
        error = new Error("Not enough SOL to perform this action");
      }

      const code = (error.message?.match("custom program error: (.*)") ||
        [])[1];
      if (code == "0x1") {
        error = new Error("Insufficient balance.");
      } else if (code === "0x0") {
        error = new Error("Blockhash expired. Please retry");
      }

      toast.custom((t) => (
        <Notification
          type="error"
          show={t.visible}
          heading={error.name}
          // @ts-ignore
          message={error.message || error.msg || error.toString()}
          onDismiss={() => toast.dismiss(t.id)}
        />
      ));
    },
    [toast]
  );

  return (
    <Wallet cluster={cluster}>
      <WalletModalProvider>
        <MarketplaceProviders onError={onError} resetCSS>{children}</MarketplaceProviders>
      </WalletModalProvider>
    </Wallet>
  );
};
